<?php
/**
 * Sample implementation of the Custom Header feature.
 *
 * @link https://developer.wordpress.org/themes/functionality/custom-headers/
 *
 * @package Theme Palace
 * @subpackage Yule
 * @since Yule 1.0.0
 */

if ( ! function_exists( 'yule_header_style' ) ) :
	/**
	 * Styles the header image and text displayed on the blog.
	 *
	 * @see yule_custom_header_setup().
	 */
	function yule_header_style() {
		$options = yule_get_theme_options();
		$css = '';

		$header_text_color = get_header_textcolor();

		/*
		 * If no custom options for text are set, let's bail.
		 * get_header_textcolor() options: Any hex value, 'blank' to hide text. Default: add_theme_support( 'custom-header' ).
		 */
		if ( get_theme_support( 'custom-header', 'default-text-color' ) === $header_text_color ) {
			return;
		}

		/*
		 * If no custom options for text are set, let's bail.
		 * get_header_textcolor() options: Any hex value, 'blank' to hide text. Default: HEADER_TEXTCOLOR.
		 */

		// If we get this far, we have custom styles. Let's do this.
		// Has the text been hidden?
		if ( ! display_header_text() ) :
			$css .='
			.site-title,
			.site-description {
				position: absolute;
				clip: rect(1px, 1px, 1px, 1px);
			}';

			// If the user has set a custom color for the text use that.
		else :
			$css .='
			.site-title a,
			#site-header .site-title a,
			.site-description {
				color: #'.esc_attr( $header_text_color ).';
			}';
		endif;
		wp_add_inline_style( 'yule-style', $css );
	}
endif;
add_action( 'wp_enqueue_scripts', 'yule_header_style', 10 );