<?php
/**
 * Popular section
 *
 * This is the template for the content of popular section
 *
 * @package Theme Palace
 * @subpackage Yule
 * @since 1.0.0
 */
if ( ! function_exists( 'yule_add_popular_section' ) ) :
  /**
   * Add popular section
   *
   *@since Yule 1.0.0
   */
  function yule_add_popular_section() {
    // Check if popular is enabled on frontpage
    $popular_enable = apply_filters( 'yule_section_status', true, 'popular_section_enable' );

    if ( true !== $popular_enable ) {
        return false;
    }

    // Get popular section details
    $section_details = array();
    $section_details = apply_filters( 'yule_filter_popular_section_details', $section_details );

    if ( empty( $section_details ) ) {
      return;
    }

    // Render popular section now.
    yule_render_popular_section( $section_details );

  }
endif;
add_action( 'yule_primary_content', 'yule_add_popular_section', 10 );


if ( ! function_exists( 'yule_get_popular_section_details' ) ) :
  /**
   * popular section details.
   *
   * @since Yule 1.0.0
   * @param array $input popular section details.
   */
  function yule_get_popular_section_details( $input ) {
    $options = yule_get_theme_options();

    // Content type.
    $popular_content_type  = $options['popular_content_type'];
    $content = array();
    switch ( $popular_content_type ) {
        case 'page':
            if ( isset( $options['popular_content_type_page'] ) ) {
                $id = $options['popular_content_type_page'];
            }
        break;

        case 'product':
            if ( isset( $options['popular_content_type_product'] ) ) {
                $id = $options['popular_content_type_product'];
            }
        break;

        default:
        break;
    }

    if( ! empty ( $id ) ) {
        // Prepare arguments.
        $args = array(
            'post_type' => $popular_content_type,
            'p'         => absint( $id ),
        );
        
        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $content_arr['title']   = get_the_title();
                $content_arr['excerpt'] = get_the_excerpt();
                $content_arr['url']     = get_permalink();
                $content_arr['img']     = get_the_post_thumbnail_url();

                if ( yule_is_woocommerce_activated() && 'product' === $popular_content_type ) {
                    global $product;
                    $cat_list             = wc_get_product_category_list( $product->get_id(), ', ' );
                    $price                = $product->get_price_html();
                    $content_arr['cat']   = $cat_list;
                    $content_arr['price'] = $price;
                }

                // Push to the main array.
                array_push( $content, $content_arr );
            endwhile;
            wp_reset_postdata();
        endif;
    }

    if ( ! empty( $content ) ) {
      $input = $content;
    }
    return $input;
  }
endif;
// popular section content details.
add_filter( 'yule_filter_popular_section_details', 'yule_get_popular_section_details' );


if ( ! function_exists( 'yule_render_popular_section' ) ) :
  /**
   * Start popular section
   *
   * @return string popular content
   * @since Yule 1.0.0
   *
   */
   function yule_render_popular_section( $content_details = array() ) {
        $options          = yule_get_theme_options();
        if ( empty( $content_details ) ) {
            return;
        } ?>
              <div id="yule_popular_section" class="relative">
                <div id="popular-product">
                    <div class="wrapper">
                        <?php foreach ( $content_details as $content ): 
                            $class = ( empty( $content['img'] ) ) ? '' : 'has-featured-image';
                            ?>
                            <article class="<?php echo esc_attr( $class ); ?>">
                                <?php if ( ! empty( $content['img'] ) ) : ?>
                                    <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['img'] );?>');">
                                    </div><!-- .featured-image -->
                                <?php endif; ?>

                                <div class="entry-container">
                                    <?php if ( isset( $content['cat'] ) ) { ?>
                                        <div class="entry-meta">
                                            <span class="cat-links"><?php echo wp_kses_post( $content['cat'] ); ?></span>
                                        </div>
                                    <?php } ?>
                                    <div class="featured-header">
                                        <h2 class="featured-product-title"><?php echo esc_html( $content['title']); ?></h2>
                                    </div><!-- .featured-header -->

                                    <div class="featured-content"><?php echo wp_kses_post( $content['excerpt'] ); ?></div><!-- .featured-content -->

                                    <?php if ( isset( $content['price'] ) ) { ?>
                                        <div class="featured-price">
                                            <span class="label"><?php esc_html_e( 'Price:', 'yule' ); ?></span>
                                            <span class="amount"><?php echo wp_kses_post( $content['price'] ); ?></span>
                                        </div><!-- .featured-price -->
                                    <?php } ?>

                                    <div class="more-link">
                                        <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn btn-primary"><?php esc_html_e( 'Shop Now', 'yule' ); ?></a>
                                    </div>
                                </div><!-- .entry-container -->
                            </article>
                        <?php endforeach; ?>
                    </div><!-- .wrapper -->
                </div><!-- #featured-product -->
              </div>
                
<?php
    }
endif;